@@ -267,6 +267,7 @@ class sprite(py.sprite.Sprite):
 class textZone(sprite):
     """class pour ajouter automatiquement du text"""
     def __init__(self, name,size:Vector2,manager, isactive=True,text_color='white', layer=0):
+        py.sprite.Sprite.__init__(self)
         self.name = name
         self.isactive = isactive
         self.layer = layer
@@ -301,7 +302,7 @@ class textZone(sprite):
         x = 0
         y = 0
         # Blit the text
-        _surf = py.Surface(self.get_size(),flags=SRCALPHA)
+        _surf = py.Surface(self.get_size()(),flags=SRCALPHA)
         for line in self.text.split("\n"):
             txt_surface = self.FONT.render(line, True,self.text_color)
             if self.aling[0]:
@@ -727,6 +728,13 @@ class Menu(py.sprite.Group):
             sprite.update()
         self.draw(self._manager.screen)
     
+    def draw(self, surface: py.Surface):
+        sprites = self.sprites()
+        if hasattr(surface, "blits"):
+            self.spritedict.update(
+                zip(sprites, surface.blits((spr.image, spr.rect) for spr in sprites if spr.isactive))
+            )
+
     def get_childs(self):
         """
         fonction pour récupérer les menus enfants
